@@ -87,10 +87,10 @@ def f2c(f):
 def ppl(code=13):
     """
     codeにある地域(デフォルトは東京)の直近の降水確率を返す
-    6時間ごと，7つ
+    6時間ごと，4つ
     """
     d = get_wf_json(code)
-    return [int(x) for x in d[0]["timeSeries"][1]["areas"][0]["pops"]]
+    return [int(x) for x in d[0]["timeSeries"][1]["areas"][0]["pops"]][:4]
 
 
 def get_eq_info():
